@@ -1,7 +1,7 @@
 package App::wordlist;
 
-our $DATE = '2016-02-06'; # DATE
-our $VERSION = '0.20'; # VERSION
+our $DATE = '2016-02-29'; # DATE
+our $VERSION = '0.21'; # VERSION
 
 use 5.010001;
 use strict;
@@ -236,7 +236,10 @@ sub wordlist {
                 my $res = App::lcpan::Call::call_lcpan_script(
                     argv => [qw/mods --namespace WordList/],
                 );
-                return [200, "OK", [grep {/WordList::/} sort @$res]];
+                return $res if $res->[0] != 200;
+                return [200, "OK",
+                        [map {s/\AWordList:://; $_}
+                             grep {/WordList::/} sort @{$res->[2]}]];
             } elsif ($method eq 'metacpan') {
                 unless (eval { require MetaCPAN::Client; 1 }) {
                     warn "MetaCPAN::Client is not installed, skipped listing ".
@@ -250,7 +253,9 @@ sub wordlist {
                 my @res;
                 while (my $row = $rs->next) {
                     my $mod = $row->module->[0]{name};
-                    push @res, $mod unless grep {$mod eq $_} @res;
+                    next unless grep {$mod eq $_} @res;
+                    $mod =~ s/\AWordList:://;
+                    push @res, $mod;
                 }
                 return [200, "OK", [sort @res]];
             }
@@ -279,7 +284,7 @@ App::wordlist - Grep words from WordList::*
 
 =head1 VERSION
 
-This document describes version 0.20 of App::wordlist (from Perl distribution App-wordlist), released on 2016-02-06.
+This document describes version 0.21 of App::wordlist (from Perl distribution App-wordlist), released on 2016-02-29.
 
 =head1 SYNOPSIS
 
